is_factory_calibration_page

Function is_factory_calibration_page 

pub const fn is_factory_calibration_page(page: u16) -> bool
Returns true if the given page is within the factory calibration region that must never be overwritten.